@@ -651,6 +651,11 @@ void extract_text(string &buffer, const char *fname)
 		read_c110_buffer(buffer);
 		if (fname) cap110_def_filename = fname;
 		select_form(selected_form);
+	} else if (buffer.find("<f126>") != string::npos) {
+		selected_form = F126;
+		f126_read_buffer(buffer);
+		if (fname) f126_def_filename = fname;
+		select_form(selected_form);
 	} else if (buffer.find("<mars_daily>") != string::npos) {
 		selected_form = MARSDAILY;
 		read_mars_daily_buffer(buffer);
@@ -843,6 +848,7 @@ int eval_transfer_size()
 		case IARU:		return eval_iaru_fsize();
 		case CAP105:	return eval_cap105_fsize();
 		case CAP110:	return eval_cap110_fsize();
+		case F126:		return eval_f126_fsize();
 		case PLAINTEXT:	return eval_pt_fsize();
 		case BLANK:		return eval_blank_fsize();
 		case CSV:		return eval_csv_fsize();
@@ -882,6 +888,7 @@ void cb_new()
 		case IARU: iaru_cb_new(); break;
 		case CAP105: cap105_cb_new(); break;
 		case CAP110: cap110_cb_new(); break;
+		case F126: f126_cb_new(); break;
 		case PLAINTEXT: cb_pt_new(); break;
 		case BLANK: cb_blank_new(); break;
 		case TRANSFER: cb_transfer_new(); break;
@@ -920,6 +927,7 @@ void cb_import()
 		case IARU: iaru_cb_import(); break;
 		case CAP105: cap105_cb_import(); break;
 		case CAP110: cap110_cb_import(); break;
+		case F126: f126_cb_import(); break;
 		case PLAINTEXT:
 		case BLANK:
 		case CSV:
@@ -957,6 +965,7 @@ void cb_export()
 		case IARU: iaru_cb_export(); break;
 		case CAP105: cap105_cb_export(); break;
 		case CAP110: cap110_cb_export(); break;
+		case F126: f126_cb_export(); break;
 		case PLAINTEXT:
 		case BLANK:
 		case CSV:
@@ -1046,6 +1055,9 @@ void wrap_import(const char *fname)
 			} else if (inpbuffer.find("<cap110>") != string::npos) {
 				selected_form = CAP110;
 				cap110_cb_wrap_import(filename, inpbuffer);
+			} else if (inpbuffer.find("<f126>") != string::npos) {
+				selected_form = F126;
+				f126_cb_wrap_import(filename, inpbuffer);
 			} else if (inpbuffer.find("<plaintext>") != string::npos) {
 				selected_form = PLAINTEXT;
 				cb_pt_wrap_import(filename, inpbuffer);
@@ -1179,6 +1191,7 @@ void cb_wrap_export()
 		case IARU: iaru_cb_wrap_export(); break;
 		case CAP105: cap105_cb_wrap_export(); break;
 		case CAP110: cap110_cb_wrap_export(); break;
+		case F126: f126_cb_wrap_export(); break;
 		case PLAINTEXT: cb_pt_wrap_export(); break;
 		case BLANK: cb_blank_wrap_export(); break;
 		case CSV: cb_csv_wrap_export(); break;
@@ -1227,6 +1240,7 @@ void cb_wrap_autosend()
 		case IARU: iaru_cb_wrap_autosend(); break;
 		case CAP105: cap105_cb_wrap_autosend(); break;
 		case CAP110: cap110_cb_wrap_autosend(); break;
+		case F126: f126_cb_wrap_autosend(); break;
 		case PLAINTEXT: cb_pt_wrap_autosend(); break;
 		case BLANK: cb_blank_wrap_autosend(); break;
 		case CSV: cb_csv_wrap_autosend(); break;
@@ -1265,6 +1279,7 @@ void cb_load_template()
 		case IARU: iaru_cb_load_template(); break;
 		case CAP105: cap105_cb_load_template(); break;
 		case CAP110: cap110_cb_load_template(); break;
+		case F126: f126_cb_load_template(); break;
 		case PLAINTEXT: cb_pt_load_template(); break;
 		case BLANK: cb_blank_load_template(); break;
 		case CSV: cb_csv_load_template(); break;
@@ -1302,6 +1317,7 @@ void cb_save_template()
 		case IARU: iaru_cb_save_template(); break;
 		case CAP105: cap105_cb_save_template(); break;
 		case CAP110: cap110_cb_save_template(); break;
+		case F126: f126_cb_save_template(); break;
 		case PLAINTEXT: cb_pt_save_template(); break;
 		case BLANK: cb_blank_save_template(); break;
 		case CSV: cb_csv_save_template(); break;
@@ -1338,6 +1354,7 @@ void cb_save_as_template()
 		case IARU: iaru_cb_save_as_template(); break;
 		case CAP105: cap105_cb_save_as_template(); break;
 		case CAP110: cap110_cb_save_as_template(); break;
+		case F126: f126_cb_save_as_template(); break;
 		case PLAINTEXT: cb_pt_save_as_template(); break;
 		case BLANK: cb_blank_save_as_template(); break;
 		case CSV: cb_csv_save_as_template(); break;
@@ -1374,6 +1391,7 @@ void cb_open()
 		case IARU: iaru_cb_open(); break;
 		case CAP105: cap105_cb_open(); break;
 		case CAP110: cap110_cb_open(); break;
+		case F126: f126_cb_open(); break;
 		case PLAINTEXT: cb_pt_open(); break;
 		case BLANK: cb_blank_open(); break;
 		case CSV: cb_csv_open(); break;
@@ -1411,6 +1429,7 @@ void cb_save_as()
 		case IARU: iaru_cb_save_as(); break;
 		case CAP105: cap105_cb_save_as(); break;
 		case CAP110: cap110_cb_save_as(); break;
+		case F126: f126_cb_save_as(); break;
 		case PLAINTEXT: cb_pt_save_as(); break;
 		case MARSDAILY: cb_mars_daily_save_as(); break;
 		case MARSINEEI: cb_mars_ineei_save_as(); break;
@@ -1447,6 +1466,7 @@ void cb_save()
 		case IARU: iaru_cb_save(); break;
 		case CAP105: cap105_cb_save(); break;
 		case CAP110: cap110_cb_save(); break;
+		case F126: f126_cb_save(); break;
 		case PLAINTEXT: cb_pt_save(); break;
 		case MARSDAILY: cb_mars_daily_save(); break;
 		case MARSINEEI: cb_mars_ineei_save(); break;
@@ -1483,6 +1503,7 @@ void cb_html()
 		case IARU : iaru_cb_html(); break;
 		case CAP105: cap105_cb_html(); break;
 		case CAP110: cap110_cb_html(); break;
+		case F126: f126_cb_html(); break;
 		case PLAINTEXT: cb_pt_html(); break;
 		case MARSDAILY: cb_mars_daily_html(); break;
 		case MARSINEEI: cb_mars_ineei_html(); break;
@@ -1541,6 +1562,7 @@ void cb_text()
 		case IARU: iaru_cb_textout(); break;
 		case CAP105: cap105_cb_textout(); break;
 		case CAP110: cap110_cb_textout(); break;
+		case F126: f126_cb_textout(); break;
 		case PLAINTEXT: cb_pt_textout(); break;
 		case MARSDAILY: cb_mars_daily_textout(); break;
 		case MARSINEEI: cb_mars_ineei_textout(); break;
@@ -1652,6 +1674,9 @@ void show_filename(string p)
 		case CAP110:
 			cap110_base_filename = fl_filename_name(p.c_str());
 			break;
+		case F126:
+			f126_base_filename = fl_filename_name(p.c_str());
+			break;
 		case PLAINTEXT:
 			base_pt_filename = fl_filename_name(p.c_str());
 			break;
@@ -1700,7 +1725,7 @@ void show_filename(string p)
 	txt_filename->redraw();
 }
 
-#define KNAME "fllog"
+#define KNAME "flmsg"
 
 #if !defined(__APPLE__) && !defined(__WOE32__) && USE_X
 Pixmap  flmsg_icon_pixmap;
@@ -1850,6 +1875,12 @@ void after_start(void *)
 	cap110_def_template_name = ICS_tmp_dir;
 	cap110_def_template_name.append("default").append(CAP105_TEMP_EXT);
 
+	f126_def_filename = ICS_msg_dir;
+	f126_def_filename.append("default").append(F126_FILE_EXT);
+	f126_def_template_name = ICS_tmp_dir;
+	f126_def_template_name.append("default").append(F126_TEMP_EXT);
+	f126_set_choices();
+
 	def_pt_filename = ICS_msg_dir;
 	def_pt_filename.append("default").append(PTFILE_EXT);
 	def_pt_TemplateName = ICS_tmp_dir;
@@ -1974,7 +2005,7 @@ int main (int argc, char *argv[])
 
 	Fl::lock();
 
-	Fl::scheme("gtk+");
+	Fl::scheme("base");
 
 	int arg_idx;
 
@@ -2143,12 +2174,21 @@ int main (int argc, char *argv[])
 	make_pixmap(&flmsg_icon_pixmap, flmsg_icon);
 	mainwindow->icon((char *)flmsg_icon_pixmap);
 	mainwindow->show(argc, argv);
+
+// read in the current window hints, then modify them to allow icon transparency
+	Pixmap mask = -1; // create pixmaps to hold the icon image and its mask
+	XWMHints* hints = XGetWMHints(fl_display, fl_xid(mainwindow));
+	hints->flags |= IconMaskHint; // ensure transparency mask is enabled for the XPM icon
+	hints->icon_mask = mask; // set the transparency mask
+	XSetWMHints(fl_display, fl_xid(mainwindow), hints);
+	XFree(hints);
+
 #else
 	mainwindow->show(argc, argv);
 #endif
 
 	if (!have_title) {
-		string main_label;
+		static string main_label;
 		main_label = PACKAGE_NAME;
 		main_label.append(": ").append(PACKAGE_VERSION);
 		expert_dialog->label(main_label.c_str());
@@ -2679,6 +2719,9 @@ int parse_args(int argc, char **argv, int& idx)
 		fname.find(CAP110_FILE_EXT) != string::npos ||
 		fname.find(CAP110_TEMP_EXT) != string::npos ||
 
+		fname.find(F126_FILE_EXT) != string::npos ||
+		fname.find(F126_TEMP_EXT) != string::npos ||
+
 		fname.find(TRANSFER_EXT) != string::npos ||
 
 		fname.find(WRAP_EXT) != string::npos ) {
