@@ -166,7 +166,7 @@ void init_cbo_modes()
 	min_modes.append("|PSK800C2|PSK800RC2");
 	min_modes.append("|PSK1000C2|PSK1000R|PSK1000RC2");
 	min_modes.append("|QPSK31|QPSK63|QPSK125|QPSK250|QPSK500");
-	min_modes.append("|THOR16|THOR22|THOR25x4|THOR50x1|THOR50x2|THOR100");
+	min_modes.append("|THOR11|THOR16|THOR22|THOR32|THOR44|THOR56|THOR25x4|THOR50x1|THOR50x2|THOR100");
 	update_cbo_modes(min_modes);
 }
 
@@ -389,6 +389,7 @@ int mSEVEREWX = SEVEREWX;
 int mSTORMREP = STORMREP;
 int mCAP105 = CAP105;
 int mCAP110 = CAP110;
+int mF126 = F126;
 int mTRANSFER = TRANSFER;
 
 Fl_Group *oldtab = (Fl_Group *)0;
@@ -611,6 +612,14 @@ static void select_cap110()
 	show_filename(cap110_def_filename);
 }
 
+static void select_f126()
+{
+	oldtab = tab_f126;
+	tab_f126->show();
+	txt_formname->value(_("RAFAC F126"));
+	show_filename(f126_def_filename);
+}
+
 static void select_csv()
 {
 	oldtab = tab_csv;
@@ -728,6 +737,9 @@ void select_form(int form)
 		case CAP110:
 			select_cap110();
 			break;
+		case F126:
+			select_f126();
+			break;
 		case CSV:
 			select_csv();
 			break;
@@ -820,9 +832,10 @@ Fl_Menu_Item menu_[] = {
  {_("Drag-n-Drop"),  0,  (Fl_Callback*)cb_mnuDragAndDrop, 0, FL_MENU_DIVIDER, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Blank"), 0,  (Fl_Callback*)cb_mnuFormSelect, &mBLANK, 0, FL_NORMAL_LABEL, 0, 14, 0},
 
- {_("CAP"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("CAP/RAFAC"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Form 105"), 0,  (Fl_Callback*)cb_mnuFormSelect, &mCAP105, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Form 110"), 0,  (Fl_Callback*)cb_mnuFormSelect, &mCAP110, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Form F126"), 0,  (Fl_Callback*)cb_mnuFormSelect, &mF126, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
 
  {_("CSV"), 0,  (Fl_Callback*)cb_mnuFormSelect, &mCSV, 0, FL_NORMAL_LABEL, 0, 14, 0},
@@ -1166,6 +1179,7 @@ Fl_Double_Window* flmsg_dialog() {
 		create_mars_tab();
 		create_cap105_tab();
 		create_cap110_tab();
+		create_f126_tab();
 		create_iaru_tab();
 		create_radiogram_tab();
 		create_plaintext_tab();
