@@ -24,14 +24,12 @@
 
 #include <string>
 
-using namespace std;
-
 typedef unsigned char t_type;
 
 class base64 {
 #define LINELEN 64
 private:
-	string output;
+	std::string output;
 	size_t iolen;
 	size_t iocp;
 	bool ateof;
@@ -43,6 +41,6 @@ private:
 public:
 	base64(bool t = false) {crlf = t; init(); };
 	~base64(){};
-	string encode(string in);
-	string decode(string in);
+	std::string encode(std::string in);
+	std::string decode(std::string in);
 };
