@@ -39,7 +39,7 @@ ICS203, ICS205, ICS205A, ICS206, ICS213, ICS214, ICS216, ICS309, NETLOG,
 HICS203, HICS206, HICS213, HICS214, IARU,
 RADIOGRAM, PLAINTEXT, BLANK, CSV, CUSTOM,
 MARSDAILY, MARSINEEI, MARSNET, MARSARMY, MARSMSG,
-WXHC, SEVEREWX, STORMREP, CAP105, CAP110, TRANSFER, CUSTOM_TRANSFER };
+WXHC, SEVEREWX, STORMREP, CAP105, CAP110, F126, TRANSFER, CUSTOM_TRANSFER };
 
 struct FIELD { std::string f_type; std::string f_data; void **w; char w_type; };
 extern FIELD fields[];
@@ -1199,7 +1199,7 @@ extern void cap105_cb_html();
 extern void cap105_cb_textout();
 
 //=====================================================================
-// CAP 105
+// CAP 110
 //=====================================================================
 
 extern std::string	cap110_def_filename;
@@ -1233,4 +1233,43 @@ extern void cap110_cb_html();
 extern void cap110_cb_msg_type();
 extern void cap110_cb_textout();
 
+//=====================================================================
+// RAFAC ACP126 / F126
+//=====================================================================
+
+extern std::string f126_base_filename;
+extern std::string f126_def_filename;
+extern std::string f126_def_template_name;
+
+extern void f126_cb_set_dtm();
+extern void f126_cb_set_rcvd_dtm();
+extern void f126_cb_set_sent_dtm();
+extern void f126_cb_nbr(Fl_Widget *wdg);
+extern void f126_cb_filter_input(Fl_Widget *wdg);
+extern void f126_clear_fields();
+extern void f126_set_choices();
+extern bool f126_check_fields();
+extern void f126_update_fields();
+extern void f126_clear_form();
+extern void f126_update_form();
+extern void f126_make_buffer(bool compress = false);
+extern void f126_read_buffer(std::string data);
+extern void f126_cb_new();
+extern void f126_cb_import();
+extern void f126_cb_export();
+extern void f126_cb_wrap_import(std::string wrapfilename, std::string inpbuffer);
+extern int  eval_f126_fsize();
+extern void f126_cb_wrap_export();
+extern void f126_cb_wrap_autosend();
+extern void f126_cb_load_template();
+extern void f126_cb_save_template();
+extern void f126_cb_save_as_template();
+extern void f126_cb_open();
+extern void f126_write(std::string s);
+extern bool f126_cb_save_as();
+extern void f126_cb_save();
+extern void f126_cb_check();
+extern void f126_cb_html();
+extern void f126_cb_textout();
+
 #endif
