@@ -1297,6 +1297,46 @@ extern Fl_Input2	*txt_110_comm_rem[23];
 
 extern void create_cap110_tab();
 
+//======================================================================
+// RAFAC (F) forms
+//======================================================================
+// F126, Radio Message
+
+extern Fl_Group	*tab_f126;
+extern Fl_Tabs	*tabs_f126;
+extern Fl_Group	*tab_f126_message;
+extern Fl_Group	*tab_f126_information;
+
+extern Fl_Input2 *f126_txt_nbr;
+extern Fl_ListBox *f126_sel_prec;
+
+extern Fl_Input2 *f126_txt_dtm;
+extern Fl_Button *f126_btn_dtm;
+
+extern Fl_Input2 *f126_txt_from;
+extern Fl_Input2 *f126_txt_to;
+extern Fl_Input2 *f126_txt_info;
+
+extern Fl_Input2 *f126_txt_subj;
+
+extern Fl_Input2 *f126_txt_grpcnt;
+extern Fl_Button *f126_btn_check;
+
+extern FTextEdit *f126_txt_msg;
+
+extern Fl_Input2 *f126_txt_rcvd_fm;
+extern Fl_Input2 *f126_txt_rcvd_dtm;
+extern Fl_Button *f126_btn_rcvd_dtm;
+
+extern Fl_Input2 *f126_txt_sent_to;
+extern Fl_Input2 *f126_txt_sent_dtm;
+extern Fl_Button *f126_btn_sent_dtm;
+
+extern Fl_Input2 *f126_txt_rcvop;
+extern Fl_Input2 *f126_txt_sendop;
+
+extern void create_f126_tab();
+
 //======================================================================
 // external std::string arrays
 //
