@@ -26,6 +26,9 @@ extern const char cap105_txt_template[];
 extern const char cap110_html_template[];
 extern const char cap110_text_template[];
 
+extern const char f126_html_template[];
+extern const char f126_txt_template[];
+
 extern const char ics203_html_template[];
 extern const char ics203_text_template[];
 extern const char ics205_html_template[];
