@@ -255,7 +255,12 @@ void set_message_icon(const char** pixmap)
 	Fl_Widget* msg = fl_message_icon();
 	msg->label("");
 	msg->align(FL_ALIGN_TOP_LEFT | FL_ALIGN_INSIDE);
-	msg->color(msg->parent()->color());
+
+	if (!msg->parent())
+		msg->color(FL_BACKGROUND_COLOR);
+	else
+		msg->color(msg->parent()->color());
+
 	msg->box(FL_NO_BOX);
 	msg->image(msg_icon = new Fl_Pixmap(pixmap));
 }
